# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: koapy/grpc/KiwoomOpenApiService.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='koapy/grpc/KiwoomOpenApiService.proto',
  package='koapy.grpc',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%koapy/grpc/KiwoomOpenApiService.proto\x12\nkoapy.grpc\"A\n\x08\x41rgument\x12\x16\n\x0cstring_value\x18\x01 \x01(\tH\x00\x12\x14\n\nlong_value\x18\x02 \x01(\x03H\x00\x42\x07\n\x05value\"D\n\x0b\x43\x61llRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\'\n\targuments\x18\x02 \x03(\x0b\x32\x14.koapy.grpc.Argument\"D\n\x0bReturnValue\x12\x16\n\x0cstring_value\x18\x01 \x01(\tH\x00\x12\x14\n\nlong_value\x18\x02 \x01(\x03H\x00\x42\x07\n\x05value\"=\n\x0c\x43\x61llResponse\x12-\n\x0creturn_value\x18\x01 \x01(\x0b\x32\x17.koapy.grpc.ReturnValue\"*\n\rListenRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05slots\x18\x02 \x03(\t\"+\n\nSingleData\x12\r\n\x05names\x18\x01 \x03(\t\x12\x0e\n\x06values\x18\x02 \x03(\t\" \n\x0eRepeatedString\x12\x0e\n\x06values\x18\x01 \x03(\t\"F\n\tMultiData\x12\r\n\x05names\x18\x01 \x03(\t\x12*\n\x06values\x18\x02 \x03(\x0b\x32\x1a.koapy.grpc.RepeatedString\"G\n\x0eListenResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\'\n\targuments\x18\x02 \x03(\x0b\x32\x14.koapy.grpc.Argument\"\x1f\n\x11StopListenRequest\x12\n\n\x02id\x18\x01 \x01(\t\"(\n\x12StopListenResponse\x12\x12\n\nsuccessful\x18\x01 \x01(\x08\"7\n\x13\x43ustomListenRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x12\n\nclass_name\x18\x02 \x01(\t\"\xa5\x01\n\x14\x43ustomListenResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\'\n\targuments\x18\x02 \x03(\x0b\x32\x14.koapy.grpc.Argument\x12+\n\x0bsingle_data\x18\x03 \x01(\x0b\x32\x16.koapy.grpc.SingleData\x12)\n\nmulti_data\x18\x04 \x01(\x0b\x32\x15.koapy.grpc.MultiData\"\x84\x01\n\x1a\x43ustomCallAndListenRequest\x12-\n\x0c\x63\x61ll_request\x18\x01 \x01(\x0b\x32\x17.koapy.grpc.CallRequest\x12\x37\n\x0elisten_request\x18\x02 \x01(\x0b\x32\x1f.koapy.grpc.CustomListenRequest\"\x99\x01\n\x1b\x43ustomCallAndListenResponse\x12\x31\n\rcall_response\x18\x01 \x01(\x0b\x32\x18.koapy.grpc.CallResponseH\x00\x12;\n\x0flisten_response\x18\x02 \x01(\x0b\x32 .koapy.grpc.CustomListenResponseH\x00\x42\n\n\x08response\"\x0e\n\x0cLoginRequest\"S\n\x1dTransactionSubscriptionTarget\x12\x0b\n\x03RET\x18\x01 \x01(\x08\x12\n\n\x02TR\x18\x02 \x01(\x08\x12\x0c\n\x04REAL\x18\x03 \x01(\x08\x12\x0b\n\x03MSG\x18\x04 \x01(\x08\"z\n\x18TransactionStopCondition\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x41\n\ncomparator\x18\x03 \x01(\x0e\x32-.koapy.grpc.TransactionStopConditionCompartor\"\xbb\x02\n\x12TransactionRequest\x12\x14\n\x0crequest_name\x18\x01 \x01(\t\x12\x18\n\x10transaction_code\x18\x02 \x01(\t\x12\x11\n\tscreen_no\x18\x03 \x01(\t\x12:\n\x06inputs\x18\x04 \x03(\x0b\x32*.koapy.grpc.TransactionRequest.InputsEntry\x12\x39\n\x06output\x18\x05 \x01(\x0b\x32).koapy.grpc.TransactionSubscriptionTarget\x12<\n\x0estop_condition\x18\x06 \x01(\x0b\x32$.koapy.grpc.TransactionStopCondition\x1a-\n\x0bInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n\x17OrderSubscriptionTarget\x12\x0b\n\x03RET\x18\x01 \x01(\x08\x12\n\n\x02TR\x18\x02 \x01(\x08\x12\x0c\n\x04REAL\x18\x03 \x01(\x08\x12\x0b\n\x03MSG\x18\x04 \x01(\x08\x12\x0e\n\x06\x43HEJAN\x18\x05 \x01(\x08\"\xf2\x01\n\x0cOrderRequest\x12\x14\n\x0crequest_name\x18\x01 \x01(\t\x12\x11\n\tscreen_no\x18\x02 \x01(\t\x12\x12\n\naccount_no\x18\x03 \x01(\t\x12\x12\n\norder_type\x18\x04 \x01(\x03\x12\x0c\n\x04\x63ode\x18\x05 \x01(\t\x12\x10\n\x08quantity\x18\x06 \x01(\x03\x12\r\n\x05price\x18\x07 \x01(\x03\x12\x12\n\nquote_type\x18\x08 \x01(\t\x12\x19\n\x11original_order_no\x18\t \x01(\t\x12\x33\n\x06target\x18\n \x01(\x0b\x32#.koapy.grpc.OrderSubscriptionTarget\"R\n\x10RealRequestFlags\x12\x12\n\ninfer_fids\x18\x01 \x01(\x08\x12\x16\n\x0ereadable_names\x18\x02 \x01(\x08\x12\x12\n\nfast_parse\x18\x03 \x01(\x08\"\x85\x01\n\x0bRealRequest\x12\x11\n\tscreen_no\x18\x01 \x01(\t\x12\x11\n\tcode_list\x18\x02 \x03(\t\x12\x10\n\x08\x66id_list\x18\x03 \x03(\x05\x12\x11\n\treal_type\x18\x04 \x01(\t\x12+\n\x05\x66lags\x18\x05 \x01(\x0b\x32\x1c.koapy.grpc.RealRequestFlags\"3\n\x12SetLogLevelRequest\x12\r\n\x05level\x18\x01 \x01(\x05\x12\x0e\n\x06logger\x18\x02 \x01(\t\"\x15\n\x13SetLogLevelResponse*\x9d\x01\n!TransactionStopConditionCompartor\x12\x19\n\x15LESS_THAN_OR_EQUAL_TO\x10\x00\x12\r\n\tLESS_THAN\x10\x01\x12\x1c\n\x18GREATER_THAN_OR_EQUAL_TO\x10\x02\x12\x10\n\x0cGREATER_THAN\x10\x03\x12\x0c\n\x08\x45QUAL_TO\x10\x04\x12\x10\n\x0cNOT_EQUAL_TO\x10\x05\x32\xdc\x06\n\x14KiwoomOpenApiService\x12;\n\x04\x43\x61ll\x12\x17.koapy.grpc.CallRequest\x1a\x18.koapy.grpc.CallResponse\"\x00\x12I\n\x06Listen\x12\x19.koapy.grpc.ListenRequest\x1a .koapy.grpc.CustomListenResponse\"\x00\x30\x01\x12M\n\nStopListen\x12\x1d.koapy.grpc.StopListenRequest\x1a\x1e.koapy.grpc.StopListenResponse\"\x00\x12U\n\x0c\x43ustomListen\x12\x1f.koapy.grpc.CustomListenRequest\x1a .koapy.grpc.CustomListenResponse\"\x00\x30\x01\x12j\n\x13\x43ustomCallAndListen\x12&.koapy.grpc.CustomCallAndListenRequest\x1a\'.koapy.grpc.CustomCallAndListenResponse\"\x00\x30\x01\x12R\n\tLoginCall\x12\x18.koapy.grpc.LoginRequest\x1a\'.koapy.grpc.CustomCallAndListenResponse\"\x00\x30\x01\x12^\n\x0fTransactionCall\x12\x1e.koapy.grpc.TransactionRequest\x1a\'.koapy.grpc.CustomCallAndListenResponse\"\x00\x30\x01\x12R\n\tOrderCall\x12\x18.koapy.grpc.OrderRequest\x1a\'.koapy.grpc.CustomCallAndListenResponse\"\x00\x30\x01\x12P\n\x08RealCall\x12\x17.koapy.grpc.RealRequest\x1a\'.koapy.grpc.CustomCallAndListenResponse\"\x00\x30\x01\x12P\n\x0bSetLogLevel\x12\x1e.koapy.grpc.SetLogLevelRequest\x1a\x1f.koapy.grpc.SetLogLevelResponse\"\x00\x62\x06proto3'
)

_TRANSACTIONSTOPCONDITIONCOMPARTOR = _descriptor.EnumDescriptor(
  name='TransactionStopConditionCompartor',
  full_name='koapy.grpc.TransactionStopConditionCompartor',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LESS_THAN_OR_EQUAL_TO', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LESS_THAN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREATER_THAN_OR_EQUAL_TO', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREATER_THAN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EQUAL_TO', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_EQUAL_TO', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2362,
  serialized_end=2519,
)
_sym_db.RegisterEnumDescriptor(_TRANSACTIONSTOPCONDITIONCOMPARTOR)

TransactionStopConditionCompartor = enum_type_wrapper.EnumTypeWrapper(_TRANSACTIONSTOPCONDITIONCOMPARTOR)
LESS_THAN_OR_EQUAL_TO = 0
LESS_THAN = 1
GREATER_THAN_OR_EQUAL_TO = 2
GREATER_THAN = 3
EQUAL_TO = 4
NOT_EQUAL_TO = 5



_ARGUMENT = _descriptor.Descriptor(
  name='Argument',
  full_name='koapy.grpc.Argument',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='string_value', full_name='koapy.grpc.Argument.string_value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='long_value', full_name='koapy.grpc.Argument.long_value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='koapy.grpc.Argument.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=53,
  serialized_end=118,
)


_CALLREQUEST = _descriptor.Descriptor(
  name='CallRequest',
  full_name='koapy.grpc.CallRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='koapy.grpc.CallRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arguments', full_name='koapy.grpc.CallRequest.arguments', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=188,
)


_RETURNVALUE = _descriptor.Descriptor(
  name='ReturnValue',
  full_name='koapy.grpc.ReturnValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='string_value', full_name='koapy.grpc.ReturnValue.string_value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='long_value', full_name='koapy.grpc.ReturnValue.long_value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='koapy.grpc.ReturnValue.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=190,
  serialized_end=258,
)


_CALLRESPONSE = _descriptor.Descriptor(
  name='CallResponse',
  full_name='koapy.grpc.CallResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='return_value', full_name='koapy.grpc.CallResponse.return_value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=260,
  serialized_end=321,
)


_LISTENREQUEST = _descriptor.Descriptor(
  name='ListenRequest',
  full_name='koapy.grpc.ListenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='koapy.grpc.ListenRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slots', full_name='koapy.grpc.ListenRequest.slots', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=323,
  serialized_end=365,
)


_SINGLEDATA = _descriptor.Descriptor(
  name='SingleData',
  full_name='koapy.grpc.SingleData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='names', full_name='koapy.grpc.SingleData.names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='koapy.grpc.SingleData.values', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=367,
  serialized_end=410,
)


_REPEATEDSTRING = _descriptor.Descriptor(
  name='RepeatedString',
  full_name='koapy.grpc.RepeatedString',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='koapy.grpc.RepeatedString.values', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=412,
  serialized_end=444,
)


_MULTIDATA = _descriptor.Descriptor(
  name='MultiData',
  full_name='koapy.grpc.MultiData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='names', full_name='koapy.grpc.MultiData.names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='koapy.grpc.MultiData.values', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=446,
  serialized_end=516,
)


_LISTENRESPONSE = _descriptor.Descriptor(
  name='ListenResponse',
  full_name='koapy.grpc.ListenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='koapy.grpc.ListenResponse.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arguments', full_name='koapy.grpc.ListenResponse.arguments', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=518,
  serialized_end=589,
)


_STOPLISTENREQUEST = _descriptor.Descriptor(
  name='StopListenRequest',
  full_name='koapy.grpc.StopListenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='koapy.grpc.StopListenRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=591,
  serialized_end=622,
)


_STOPLISTENRESPONSE = _descriptor.Descriptor(
  name='StopListenResponse',
  full_name='koapy.grpc.StopListenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='successful', full_name='koapy.grpc.StopListenResponse.successful', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=624,
  serialized_end=664,
)


_CUSTOMLISTENREQUEST = _descriptor.Descriptor(
  name='CustomListenRequest',
  full_name='koapy.grpc.CustomListenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='koapy.grpc.CustomListenRequest.code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='class_name', full_name='koapy.grpc.CustomListenRequest.class_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=666,
  serialized_end=721,
)


_CUSTOMLISTENRESPONSE = _descriptor.Descriptor(
  name='CustomListenResponse',
  full_name='koapy.grpc.CustomListenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='koapy.grpc.CustomListenResponse.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arguments', full_name='koapy.grpc.CustomListenResponse.arguments', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='single_data', full_name='koapy.grpc.CustomListenResponse.single_data', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multi_data', full_name='koapy.grpc.CustomListenResponse.multi_data', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=724,
  serialized_end=889,
)


_CUSTOMCALLANDLISTENREQUEST = _descriptor.Descriptor(
  name='CustomCallAndListenRequest',
  full_name='koapy.grpc.CustomCallAndListenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_request', full_name='koapy.grpc.CustomCallAndListenRequest.call_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listen_request', full_name='koapy.grpc.CustomCallAndListenRequest.listen_request', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=892,
  serialized_end=1024,
)


_CUSTOMCALLANDLISTENRESPONSE = _descriptor.Descriptor(
  name='CustomCallAndListenResponse',
  full_name='koapy.grpc.CustomCallAndListenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_response', full_name='koapy.grpc.CustomCallAndListenResponse.call_response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listen_response', full_name='koapy.grpc.CustomCallAndListenResponse.listen_response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='response', full_name='koapy.grpc.CustomCallAndListenResponse.response',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1027,
  serialized_end=1180,
)


_LOGINREQUEST = _descriptor.Descriptor(
  name='LoginRequest',
  full_name='koapy.grpc.LoginRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1182,
  serialized_end=1196,
)


_TRANSACTIONSUBSCRIPTIONTARGET = _descriptor.Descriptor(
  name='TransactionSubscriptionTarget',
  full_name='koapy.grpc.TransactionSubscriptionTarget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='RET', full_name='koapy.grpc.TransactionSubscriptionTarget.RET', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='TR', full_name='koapy.grpc.TransactionSubscriptionTarget.TR', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='REAL', full_name='koapy.grpc.TransactionSubscriptionTarget.REAL', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='MSG', full_name='koapy.grpc.TransactionSubscriptionTarget.MSG', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1198,
  serialized_end=1281,
)


_TRANSACTIONSTOPCONDITION = _descriptor.Descriptor(
  name='TransactionStopCondition',
  full_name='koapy.grpc.TransactionStopCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='koapy.grpc.TransactionStopCondition.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='koapy.grpc.TransactionStopCondition.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='comparator', full_name='koapy.grpc.TransactionStopCondition.comparator', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1283,
  serialized_end=1405,
)


_TRANSACTIONREQUEST_INPUTSENTRY = _descriptor.Descriptor(
  name='InputsEntry',
  full_name='koapy.grpc.TransactionRequest.InputsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='koapy.grpc.TransactionRequest.InputsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='koapy.grpc.TransactionRequest.InputsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1678,
  serialized_end=1723,
)

_TRANSACTIONREQUEST = _descriptor.Descriptor(
  name='TransactionRequest',
  full_name='koapy.grpc.TransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_name', full_name='koapy.grpc.TransactionRequest.request_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transaction_code', full_name='koapy.grpc.TransactionRequest.transaction_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='screen_no', full_name='koapy.grpc.TransactionRequest.screen_no', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='koapy.grpc.TransactionRequest.inputs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output', full_name='koapy.grpc.TransactionRequest.output', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_condition', full_name='koapy.grpc.TransactionRequest.stop_condition', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TRANSACTIONREQUEST_INPUTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1408,
  serialized_end=1723,
)


_ORDERSUBSCRIPTIONTARGET = _descriptor.Descriptor(
  name='OrderSubscriptionTarget',
  full_name='koapy.grpc.OrderSubscriptionTarget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='RET', full_name='koapy.grpc.OrderSubscriptionTarget.RET', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='TR', full_name='koapy.grpc.OrderSubscriptionTarget.TR', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='REAL', full_name='koapy.grpc.OrderSubscriptionTarget.REAL', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='MSG', full_name='koapy.grpc.OrderSubscriptionTarget.MSG', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='CHEJAN', full_name='koapy.grpc.OrderSubscriptionTarget.CHEJAN', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1725,
  serialized_end=1818,
)


_ORDERREQUEST = _descriptor.Descriptor(
  name='OrderRequest',
  full_name='koapy.grpc.OrderRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_name', full_name='koapy.grpc.OrderRequest.request_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='screen_no', full_name='koapy.grpc.OrderRequest.screen_no', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account_no', full_name='koapy.grpc.OrderRequest.account_no', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_type', full_name='koapy.grpc.OrderRequest.order_type', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='koapy.grpc.OrderRequest.code', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='koapy.grpc.OrderRequest.quantity', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='koapy.grpc.OrderRequest.price', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_type', full_name='koapy.grpc.OrderRequest.quote_type', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='original_order_no', full_name='koapy.grpc.OrderRequest.original_order_no', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='koapy.grpc.OrderRequest.target', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1821,
  serialized_end=2063,
)


_REALREQUESTFLAGS = _descriptor.Descriptor(
  name='RealRequestFlags',
  full_name='koapy.grpc.RealRequestFlags',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='infer_fids', full_name='koapy.grpc.RealRequestFlags.infer_fids', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readable_names', full_name='koapy.grpc.RealRequestFlags.readable_names', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fast_parse', full_name='koapy.grpc.RealRequestFlags.fast_parse', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2065,
  serialized_end=2147,
)


_REALREQUEST = _descriptor.Descriptor(
  name='RealRequest',
  full_name='koapy.grpc.RealRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='screen_no', full_name='koapy.grpc.RealRequest.screen_no', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code_list', full_name='koapy.grpc.RealRequest.code_list', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fid_list', full_name='koapy.grpc.RealRequest.fid_list', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='real_type', full_name='koapy.grpc.RealRequest.real_type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='koapy.grpc.RealRequest.flags', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2150,
  serialized_end=2283,
)


_SETLOGLEVELREQUEST = _descriptor.Descriptor(
  name='SetLogLevelRequest',
  full_name='koapy.grpc.SetLogLevelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='level', full_name='koapy.grpc.SetLogLevelRequest.level', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logger', full_name='koapy.grpc.SetLogLevelRequest.logger', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2285,
  serialized_end=2336,
)


_SETLOGLEVELRESPONSE = _descriptor.Descriptor(
  name='SetLogLevelResponse',
  full_name='koapy.grpc.SetLogLevelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2338,
  serialized_end=2359,
)

_ARGUMENT.oneofs_by_name['value'].fields.append(
  _ARGUMENT.fields_by_name['string_value'])
_ARGUMENT.fields_by_name['string_value'].containing_oneof = _ARGUMENT.oneofs_by_name['value']
_ARGUMENT.oneofs_by_name['value'].fields.append(
  _ARGUMENT.fields_by_name['long_value'])
_ARGUMENT.fields_by_name['long_value'].containing_oneof = _ARGUMENT.oneofs_by_name['value']
_CALLREQUEST.fields_by_name['arguments'].message_type = _ARGUMENT
_RETURNVALUE.oneofs_by_name['value'].fields.append(
  _RETURNVALUE.fields_by_name['string_value'])
_RETURNVALUE.fields_by_name['string_value'].containing_oneof = _RETURNVALUE.oneofs_by_name['value']
_RETURNVALUE.oneofs_by_name['value'].fields.append(
  _RETURNVALUE.fields_by_name['long_value'])
_RETURNVALUE.fields_by_name['long_value'].containing_oneof = _RETURNVALUE.oneofs_by_name['value']
_CALLRESPONSE.fields_by_name['return_value'].message_type = _RETURNVALUE
_MULTIDATA.fields_by_name['values'].message_type = _REPEATEDSTRING
_LISTENRESPONSE.fields_by_name['arguments'].message_type = _ARGUMENT
_CUSTOMLISTENRESPONSE.fields_by_name['arguments'].message_type = _ARGUMENT
_CUSTOMLISTENRESPONSE.fields_by_name['single_data'].message_type = _SINGLEDATA
_CUSTOMLISTENRESPONSE.fields_by_name['multi_data'].message_type = _MULTIDATA
_CUSTOMCALLANDLISTENREQUEST.fields_by_name['call_request'].message_type = _CALLREQUEST
_CUSTOMCALLANDLISTENREQUEST.fields_by_name['listen_request'].message_type = _CUSTOMLISTENREQUEST
_CUSTOMCALLANDLISTENRESPONSE.fields_by_name['call_response'].message_type = _CALLRESPONSE
_CUSTOMCALLANDLISTENRESPONSE.fields_by_name['listen_response'].message_type = _CUSTOMLISTENRESPONSE
_CUSTOMCALLANDLISTENRESPONSE.oneofs_by_name['response'].fields.append(
  _CUSTOMCALLANDLISTENRESPONSE.fields_by_name['call_response'])
_CUSTOMCALLANDLISTENRESPONSE.fields_by_name['call_response'].containing_oneof = _CUSTOMCALLANDLISTENRESPONSE.oneofs_by_name['response']
_CUSTOMCALLANDLISTENRESPONSE.oneofs_by_name['response'].fields.append(
  _CUSTOMCALLANDLISTENRESPONSE.fields_by_name['listen_response'])
_CUSTOMCALLANDLISTENRESPONSE.fields_by_name['listen_response'].containing_oneof = _CUSTOMCALLANDLISTENRESPONSE.oneofs_by_name['response']
_TRANSACTIONSTOPCONDITION.fields_by_name['comparator'].enum_type = _TRANSACTIONSTOPCONDITIONCOMPARTOR
_TRANSACTIONREQUEST_INPUTSENTRY.containing_type = _TRANSACTIONREQUEST
_TRANSACTIONREQUEST.fields_by_name['inputs'].message_type = _TRANSACTIONREQUEST_INPUTSENTRY
_TRANSACTIONREQUEST.fields_by_name['output'].message_type = _TRANSACTIONSUBSCRIPTIONTARGET
_TRANSACTIONREQUEST.fields_by_name['stop_condition'].message_type = _TRANSACTIONSTOPCONDITION
_ORDERREQUEST.fields_by_name['target'].message_type = _ORDERSUBSCRIPTIONTARGET
_REALREQUEST.fields_by_name['flags'].message_type = _REALREQUESTFLAGS
DESCRIPTOR.message_types_by_name['Argument'] = _ARGUMENT
DESCRIPTOR.message_types_by_name['CallRequest'] = _CALLREQUEST
DESCRIPTOR.message_types_by_name['ReturnValue'] = _RETURNVALUE
DESCRIPTOR.message_types_by_name['CallResponse'] = _CALLRESPONSE
DESCRIPTOR.message_types_by_name['ListenRequest'] = _LISTENREQUEST
DESCRIPTOR.message_types_by_name['SingleData'] = _SINGLEDATA
DESCRIPTOR.message_types_by_name['RepeatedString'] = _REPEATEDSTRING
DESCRIPTOR.message_types_by_name['MultiData'] = _MULTIDATA
DESCRIPTOR.message_types_by_name['ListenResponse'] = _LISTENRESPONSE
DESCRIPTOR.message_types_by_name['StopListenRequest'] = _STOPLISTENREQUEST
DESCRIPTOR.message_types_by_name['StopListenResponse'] = _STOPLISTENRESPONSE
DESCRIPTOR.message_types_by_name['CustomListenRequest'] = _CUSTOMLISTENREQUEST
DESCRIPTOR.message_types_by_name['CustomListenResponse'] = _CUSTOMLISTENRESPONSE
DESCRIPTOR.message_types_by_name['CustomCallAndListenRequest'] = _CUSTOMCALLANDLISTENREQUEST
DESCRIPTOR.message_types_by_name['CustomCallAndListenResponse'] = _CUSTOMCALLANDLISTENRESPONSE
DESCRIPTOR.message_types_by_name['LoginRequest'] = _LOGINREQUEST
DESCRIPTOR.message_types_by_name['TransactionSubscriptionTarget'] = _TRANSACTIONSUBSCRIPTIONTARGET
DESCRIPTOR.message_types_by_name['TransactionStopCondition'] = _TRANSACTIONSTOPCONDITION
DESCRIPTOR.message_types_by_name['TransactionRequest'] = _TRANSACTIONREQUEST
DESCRIPTOR.message_types_by_name['OrderSubscriptionTarget'] = _ORDERSUBSCRIPTIONTARGET
DESCRIPTOR.message_types_by_name['OrderRequest'] = _ORDERREQUEST
DESCRIPTOR.message_types_by_name['RealRequestFlags'] = _REALREQUESTFLAGS
DESCRIPTOR.message_types_by_name['RealRequest'] = _REALREQUEST
DESCRIPTOR.message_types_by_name['SetLogLevelRequest'] = _SETLOGLEVELREQUEST
DESCRIPTOR.message_types_by_name['SetLogLevelResponse'] = _SETLOGLEVELRESPONSE
DESCRIPTOR.enum_types_by_name['TransactionStopConditionCompartor'] = _TRANSACTIONSTOPCONDITIONCOMPARTOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Argument = _reflection.GeneratedProtocolMessageType('Argument', (_message.Message,), {
  'DESCRIPTOR' : _ARGUMENT,
  '__module__' : 'koapy.grpc.KiwoomOpenApiService_pb2'
  # @@protoc_insertion_point(class_scope:koapy.grpc.Argument)
  })
_sym_db.RegisterMessage(Argument)

CallRequest = _reflection.GeneratedProtocolMessageType('CallRequest', (_message.Message,), {
  'DESCRIPTOR' : _CALLREQUEST,
  '__module__' : 'koapy.grpc.KiwoomOpenApiService_pb2'
  # @@protoc_insertion_point(class_scope:koapy.grpc.CallRequest)
  })
_sym_db.RegisterMessage(CallRequest)

ReturnValue = _reflection.GeneratedProtocolMessageType('ReturnValue', (_message.Message,), {
  'DESCRIPTOR' : _RETURNVALUE,
  '__module__' : 'koapy.grpc.KiwoomOpenApiService_pb2'
  # @@protoc_insertion_point(class_scope:koapy.grpc.ReturnValue)
  })
_sym_db.RegisterMessage(ReturnValue)

CallResponse = _reflection.GeneratedProtocolMessageType('CallResponse', (_message.Message,), {
  'DESCRIPTOR' : _CALLRESPONSE,
  '__module__' : 'koapy.grpc.KiwoomOpenApiService_pb2'
  # @@protoc_insertion_point(class_scope:koapy.grpc.CallResponse)
  })
_sym_db.RegisterMessage(CallResponse)

ListenRequest = _reflection.GeneratedProtocolMessageType('ListenRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTENREQUEST,
  '__module__' : 'koapy.grpc.KiwoomOpenApiService_pb2'
  # @@protoc_insertion_point(class_scope:koapy.grpc.ListenRequest)
  })
_sym_db.RegisterMessage(ListenRequest)

SingleData = _reflection.GeneratedProtocolMessageType('SingleData', (_message.Message,), {
  'DESCRIPTOR' : _SINGLEDATA,
  '__module__' : 'koapy.grpc.KiwoomOpenApiService_pb2'
  # @@protoc_insertion_point(class_scope:koapy.grpc.SingleData)
  })
_sym_db.RegisterMessage(SingleData)

RepeatedString = _reflection.GeneratedProtocolMessageType('RepeatedString', (_message.Message,), {
  'DESCRIPTOR' : _REPEATEDSTRING,
  '__module__' : 'koapy.grpc.KiwoomOpenApiService_pb2'
  # @@protoc_insertion_point(class_scope:koapy.grpc.RepeatedString)
  })
_sym_db.RegisterMessage(RepeatedString)

MultiData = _reflection.GeneratedProtocolMessageType('MultiData', (_message.Message,), {
  'DESCRIPTOR' : _MULTIDATA,
  '__module__' : 'koapy.grpc.KiwoomOpenApiService_pb2'
  # @@protoc_insertion_point(class_scope:koapy.grpc.MultiData)
  })
_sym_db.RegisterMessage(MultiData)

ListenResponse = _reflection.GeneratedProtocolMessageType('ListenResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTENRESPONSE,
  '__module__' : 'koapy.grpc.KiwoomOpenApiService_pb2'
  # @@protoc_insertion_point(class_scope:koapy.grpc.ListenResponse)
  })
_sym_db.RegisterMessage(ListenResponse)

StopListenRequest = _reflection.GeneratedProtocolMessageType('StopListenRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPLISTENREQUEST,
  '__module__' : 'koapy.grpc.KiwoomOpenApiService_pb2'
  # @@protoc_insertion_point(class_scope:koapy.grpc.StopListenRequest)
  })
_sym_db.RegisterMessage(StopListenRequest)

StopListenResponse = _reflection.GeneratedProtocolMessageType('StopListenResponse', (_message.Message,), {
  'DESCRIPTOR' : _STOPLISTENRESPONSE,
  '__module__' : 'koapy.grpc.KiwoomOpenApiService_pb2'
  # @@protoc_insertion_point(class_scope:koapy.grpc.StopListenResponse)
  })
_sym_db.RegisterMessage(StopListenResponse)

CustomListenRequest = _reflection.GeneratedProtocolMessageType('CustomListenRequest', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMLISTENREQUEST,
  '__module__' : 'koapy.grpc.KiwoomOpenApiService_pb2'
  # @@protoc_insertion_point(class_scope:koapy.grpc.CustomListenRequest)
  })
_sym_db.RegisterMessage(CustomListenRequest)

CustomListenResponse = _reflection.GeneratedProtocolMessageType('CustomListenResponse', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMLISTENRESPONSE,
  '__module__' : 'koapy.grpc.KiwoomOpenApiService_pb2'
  # @@protoc_insertion_point(class_scope:koapy.grpc.CustomListenResponse)
  })
_sym_db.RegisterMessage(CustomListenResponse)

CustomCallAndListenRequest = _reflection.GeneratedProtocolMessageType('CustomCallAndListenRequest', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMCALLANDLISTENREQUEST,
  '__module__' : 'koapy.grpc.KiwoomOpenApiService_pb2'
  # @@protoc_insertion_point(class_scope:koapy.grpc.CustomCallAndListenRequest)
  })
_sym_db.RegisterMessage(CustomCallAndListenRequest)

CustomCallAndListenResponse = _reflection.GeneratedProtocolMessageType('CustomCallAndListenResponse', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMCALLANDLISTENRESPONSE,
  '__module__' : 'koapy.grpc.KiwoomOpenApiService_pb2'
  # @@protoc_insertion_point(class_scope:koapy.grpc.CustomCallAndListenResponse)
  })
_sym_db.RegisterMessage(CustomCallAndListenResponse)

LoginRequest = _reflection.GeneratedProtocolMessageType('LoginRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOGINREQUEST,
  '__module__' : 'koapy.grpc.KiwoomOpenApiService_pb2'
  # @@protoc_insertion_point(class_scope:koapy.grpc.LoginRequest)
  })
_sym_db.RegisterMessage(LoginRequest)

TransactionSubscriptionTarget = _reflection.GeneratedProtocolMessageType('TransactionSubscriptionTarget', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONSUBSCRIPTIONTARGET,
  '__module__' : 'koapy.grpc.KiwoomOpenApiService_pb2'
  # @@protoc_insertion_point(class_scope:koapy.grpc.TransactionSubscriptionTarget)
  })
_sym_db.RegisterMessage(TransactionSubscriptionTarget)

TransactionStopCondition = _reflection.GeneratedProtocolMessageType('TransactionStopCondition', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONSTOPCONDITION,
  '__module__' : 'koapy.grpc.KiwoomOpenApiService_pb2'
  # @@protoc_insertion_point(class_scope:koapy.grpc.TransactionStopCondition)
  })
_sym_db.RegisterMessage(TransactionStopCondition)

TransactionRequest = _reflection.GeneratedProtocolMessageType('TransactionRequest', (_message.Message,), {

  'InputsEntry' : _reflection.GeneratedProtocolMessageType('InputsEntry', (_message.Message,), {
    'DESCRIPTOR' : _TRANSACTIONREQUEST_INPUTSENTRY,
    '__module__' : 'koapy.grpc.KiwoomOpenApiService_pb2'
    # @@protoc_insertion_point(class_scope:koapy.grpc.TransactionRequest.InputsEntry)
    })
  ,
  'DESCRIPTOR' : _TRANSACTIONREQUEST,
  '__module__' : 'koapy.grpc.KiwoomOpenApiService_pb2'
  # @@protoc_insertion_point(class_scope:koapy.grpc.TransactionRequest)
  })
_sym_db.RegisterMessage(TransactionRequest)
_sym_db.RegisterMessage(TransactionRequest.InputsEntry)

OrderSubscriptionTarget = _reflection.GeneratedProtocolMessageType('OrderSubscriptionTarget', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSUBSCRIPTIONTARGET,
  '__module__' : 'koapy.grpc.KiwoomOpenApiService_pb2'
  # @@protoc_insertion_point(class_scope:koapy.grpc.OrderSubscriptionTarget)
  })
_sym_db.RegisterMessage(OrderSubscriptionTarget)

OrderRequest = _reflection.GeneratedProtocolMessageType('OrderRequest', (_message.Message,), {
  'DESCRIPTOR' : _ORDERREQUEST,
  '__module__' : 'koapy.grpc.KiwoomOpenApiService_pb2'
  # @@protoc_insertion_point(class_scope:koapy.grpc.OrderRequest)
  })
_sym_db.RegisterMessage(OrderRequest)

RealRequestFlags = _reflection.GeneratedProtocolMessageType('RealRequestFlags', (_message.Message,), {
  'DESCRIPTOR' : _REALREQUESTFLAGS,
  '__module__' : 'koapy.grpc.KiwoomOpenApiService_pb2'
  # @@protoc_insertion_point(class_scope:koapy.grpc.RealRequestFlags)
  })
_sym_db.RegisterMessage(RealRequestFlags)

RealRequest = _reflection.GeneratedProtocolMessageType('RealRequest', (_message.Message,), {
  'DESCRIPTOR' : _REALREQUEST,
  '__module__' : 'koapy.grpc.KiwoomOpenApiService_pb2'
  # @@protoc_insertion_point(class_scope:koapy.grpc.RealRequest)
  })
_sym_db.RegisterMessage(RealRequest)

SetLogLevelRequest = _reflection.GeneratedProtocolMessageType('SetLogLevelRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETLOGLEVELREQUEST,
  '__module__' : 'koapy.grpc.KiwoomOpenApiService_pb2'
  # @@protoc_insertion_point(class_scope:koapy.grpc.SetLogLevelRequest)
  })
_sym_db.RegisterMessage(SetLogLevelRequest)

SetLogLevelResponse = _reflection.GeneratedProtocolMessageType('SetLogLevelResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETLOGLEVELRESPONSE,
  '__module__' : 'koapy.grpc.KiwoomOpenApiService_pb2'
  # @@protoc_insertion_point(class_scope:koapy.grpc.SetLogLevelResponse)
  })
_sym_db.RegisterMessage(SetLogLevelResponse)


_TRANSACTIONREQUEST_INPUTSENTRY._options = None

_KIWOOMOPENAPISERVICE = _descriptor.ServiceDescriptor(
  name='KiwoomOpenApiService',
  full_name='koapy.grpc.KiwoomOpenApiService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2522,
  serialized_end=3382,
  methods=[
  _descriptor.MethodDescriptor(
    name='Call',
    full_name='koapy.grpc.KiwoomOpenApiService.Call',
    index=0,
    containing_service=None,
    input_type=_CALLREQUEST,
    output_type=_CALLRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Listen',
    full_name='koapy.grpc.KiwoomOpenApiService.Listen',
    index=1,
    containing_service=None,
    input_type=_LISTENREQUEST,
    output_type=_CUSTOMLISTENRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StopListen',
    full_name='koapy.grpc.KiwoomOpenApiService.StopListen',
    index=2,
    containing_service=None,
    input_type=_STOPLISTENREQUEST,
    output_type=_STOPLISTENRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CustomListen',
    full_name='koapy.grpc.KiwoomOpenApiService.CustomListen',
    index=3,
    containing_service=None,
    input_type=_CUSTOMLISTENREQUEST,
    output_type=_CUSTOMLISTENRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CustomCallAndListen',
    full_name='koapy.grpc.KiwoomOpenApiService.CustomCallAndListen',
    index=4,
    containing_service=None,
    input_type=_CUSTOMCALLANDLISTENREQUEST,
    output_type=_CUSTOMCALLANDLISTENRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LoginCall',
    full_name='koapy.grpc.KiwoomOpenApiService.LoginCall',
    index=5,
    containing_service=None,
    input_type=_LOGINREQUEST,
    output_type=_CUSTOMCALLANDLISTENRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TransactionCall',
    full_name='koapy.grpc.KiwoomOpenApiService.TransactionCall',
    index=6,
    containing_service=None,
    input_type=_TRANSACTIONREQUEST,
    output_type=_CUSTOMCALLANDLISTENRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OrderCall',
    full_name='koapy.grpc.KiwoomOpenApiService.OrderCall',
    index=7,
    containing_service=None,
    input_type=_ORDERREQUEST,
    output_type=_CUSTOMCALLANDLISTENRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RealCall',
    full_name='koapy.grpc.KiwoomOpenApiService.RealCall',
    index=8,
    containing_service=None,
    input_type=_REALREQUEST,
    output_type=_CUSTOMCALLANDLISTENRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetLogLevel',
    full_name='koapy.grpc.KiwoomOpenApiService.SetLogLevel',
    index=9,
    containing_service=None,
    input_type=_SETLOGLEVELREQUEST,
    output_type=_SETLOGLEVELRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_KIWOOMOPENAPISERVICE)

DESCRIPTOR.services_by_name['KiwoomOpenApiService'] = _KIWOOMOPENAPISERVICE

# @@protoc_insertion_point(module_scope)
